@@ -1,11 +1,10 @@
 package MARC::File::SAX;
 
 ## no POD here since you don't really want to use this module
-## directly. Look at MARC::File::XML instead.
+## directly. Look at MARC::File::SAX instead.
 ##
 ## MARC::File::SAX is a SAX handler for parsing XML encoded using the 
-## MARC21slim XML schema from the Library of Congress. It builds a MARC::Record
-## object up from SAX events.
+## MARC21slim XML schema from the Library of Congress. 
 ##
 ## For more details see: http://www.loc.gov/standards/marcxml/
 
@@ -13,7 +12,6 @@ use strict;
 use XML::SAX;
 use base qw( XML::SAX::Base );
 use Data::Dumper;
-use MARC::Charset qw(utf8_to_marc8);
 
 sub start_element {
     my ( $self, $element ) = @_;
@@ -35,19 +33,15 @@ sub end_element {
     my ( $self, $element ) = @_;
     my $name = $element->{ Name };
     if ( $name eq 'subfield' ) { 
-	push @{ $self->{ subfields } }, $self->{ subcode };
-	
-	if ($self->{ transcode }) {
-           push @{ $self->{ subfields } }, utf8_to_marc8($self->{ chars });
-	} else {
-           push @{ $self->{ subfields } }, $self->{ chars } ;
-	}
-
+	push( @{ $self->{ subfields } }, $self->{ subcode }, $self->{ chars } );
 	$self->{ chars } = '';
 	$self->{ subcode } = '';
     } elsif ( $name eq 'controlfield' ) { 
 	$self->{ record }->append_fields(
-	    MARC::Field->new( $self->{ tag }, $self->{ chars } )
+	    MARC::Field->new(
+		$self->{ tag },
+		$self->{ chars }
+	    )
 	);
 	$self->{ chars } = '';
 	$self->{ tag } = '';
@@ -66,12 +60,7 @@ sub end_element {
 	$self->{ subfields } = [];
 	$self->{ chars } = '';
     } elsif ( $name eq 'leader' ) { 
-	my $ldr = $self->{ chars };
-	$self->{ transcode }++
-		if (substr($ldr,9,1) eq 'a' and $self->{toMARC8});
-	
-	substr($ldr,9,1,' ') if ($self->{ transcode });
-	$self->{ record }->leader( $ldr );
+	$self->{ record }->leader( $self->{ chars } );
 	$self->{ chars } = '';
 	$self->{ tag } = '';
     }
@@ -80,8 +69,7 @@ sub end_element {
 
 sub characters {
     my ( $self, $chars ) = @_;
-    if ( $self->{ subcode } or ( $self->{ tag } and 
-	( $self->{ tag } eq 'LDR' or $self->{ tag } < 10 ) ) ) { 
+    if ( $self->{ subcode } or ( $self->{ tag } and $self->{ tag } < 10 ) ) { 
 	$self->{ chars } .= $chars->{ Data };
     } 
 }
